SumSquare

Struct SumSquare 

pub struct SumSquare<'a> { /* private fields */ }
Computes the sum of squares of a sequence of numbers.

This is conceptually equivalent to slice.iter().map(|&x| x * x).sum() but more efficient as it computes multiple partial sums in parallel using SIMD and then sums across the SIMD lanes at the end. This will produce very slightly different results because the additions are happening in a different order.

Implementations

Source

impl<'a> SumSquare<'a>

pub fn new(input: &'a [f32]) -> Self